@@ -218,6 +218,15 @@ def main():
         dest='build',
     )
 
+    base_group.add_argument(
+        '--download', '--download',
+        help='Downloads the required GTDB, EggNOG, & CheckM2 databases if required',
+        type=str2bool,
+        nargs='?',
+        const=True,
+        dest='download',
+    )
+
     base_group.add_argument(
         '--snakemake-cmds',
         help='Additional commands to supplied to snakemake in the form of a single string'
@@ -398,6 +407,13 @@ def main():
         default=None,
     )
 
+    annotation_group.add_argument(
+        '--checkm2-db-path', '--checkm2_db_path',
+        help='Path to Checkm2 Database',
+        dest='checkm2_db_path',
+        required=False,
+    )
+
     ####################################################################
 
     binning_group = argparse.ArgumentParser(formatter_class=CustomHelpFormatter,
@@ -602,7 +618,7 @@ def main():
     recover_options = subparsers.add_parser('recover',
                                             description='The complete binning pipeline',
                                             formatter_class=CustomHelpFormatter,
-                                            parents=[qc_group, short_read_group, long_read_group, binning_group, base_group],
+                                            parents=[qc_group, short_read_group, long_read_group, binning_group, annotation_group, base_group],
                                             epilog=
     '''
                                            ......:::::: RECOVER ::::::......
@@ -627,13 +643,6 @@ def main():
         default=['recover_mags'],
     )
 
-    recover_options.add_argument(
-        '--checkm2-db-path', '--checkm2_db_path',
-        help=argparse.SUPPRESS,
-        dest='checkm2_db_path',
-        required=False,
-    )
-
     recover_options.add_argument(
         '--perform-strain-analysis', '--perform_strain_analysis',
         help='Specify whether to use Lorikeet on recovered MAGs get strain diversity metrics',
@@ -647,7 +656,7 @@ def main():
     ##########################  ~ ANNOTATE ~   ###########################
 
     annotate_options = subparsers.add_parser('annotate',
-                                              description='Annotate a given set of MAGs using EggNog',
+                                              description='Annotate a given set of MAGs using EggNOG, GTDB-tk, and Checkm2',
                                               formatter_class=CustomHelpFormatter,
                                               parents=[mag_group, annotation_group, base_group, qc_group],
                                               epilog=
@@ -679,7 +688,8 @@ def main():
     diversity_options = subparsers.add_parser('diversity',
                                              description='Perform strain diversity analysis',
                                              formatter_class=CustomHelpFormatter,
-                                             parents=[qc_group, short_read_group, long_read_group, binning_group, base_group],
+                                             parents=[mag_group, qc_group, short_read_group, long_read_group,
+                                                      binning_group, annotation_group, base_group],
                                              epilog=
                                              '''
                                                                     ......:::::: DIVERSITY ::::::......
@@ -688,6 +698,14 @@ def main():
 
                                              ''')
 
+    diversity_options.add_argument(
+        '-a', '--assembly',
+        help='FASTA file containing scaffolded contigs of one or more metagenome assemblies wishing to be passed to QUAST',
+        dest="assembly",
+        nargs="*",
+        required=False,
+    )
+
     diversity_options.add_argument(
         '-w', '--workflow',
         help='Main workflow to run',
@@ -800,23 +818,17 @@ def main():
     ##########################   ~ configure ~  ###########################
 
     configure_options = subparsers.add_parser('configure',
-                                            description='Sets the conda environment variables for future runs. ',
+                                            description='Sets the conda environment variables for future runs and downloads databases. ',
                                             formatter_class=CustomHelpFormatter,
+                                            parents=[base_group],
                                             epilog=
                                             '''
                                                                ......:::::: CONFIGURE ::::::......
 
-                                            aviary configure --conda-prefix ~/.conda --gtdb-path ~/gtdbtk/release202/ 
+                                            aviary configure --conda-prefix ~/.conda --gtdb-path ~/gtdbtk/release207/ 
 
                                             ''')
 
-    configure_options.add_argument(
-        '--conda-prefix', '--conda_prefix',
-        help='Path to the location of installed conda environments, or where to install new environments',
-        dest='conda_prefix',
-        required=False,
-    )
-
     configure_options.add_argument(
         '--gtdb-path', '--gtdb_path',
         help='Path to the local gtdb database files',
@@ -831,16 +843,9 @@ def main():
         required=False,
     )
 
-    # configure_options.add_argument(
-    #     '--enrichm-db-path', '--enrichm_db_path',
-    #     help='Path to the local EnrichM database files',
-    #     dest='enrichm_db_path',
-    #     required=False,
-    # )
-
     configure_options.add_argument(
         '--checkm2-db-path', '--checkm2_db_path',
-        help=argparse.SUPPRESS,
+        help='Path to Checkm2 Database',
         dest='checkm2_db_path',
         required=False,
     )
@@ -852,14 +857,13 @@ def main():
         required=False,
     )
 
-    # configure_options.add_argument(
-    #     '--build',
-    #     help='Build conda environments and then exits. Equivalent to \"--snakemake-cmds \'--conda-create-envs-only True \' \"',
-    #     type=str2bool,
-    #     nargs='?',
-    #     const=True,
-    #     dest='build',
-    # )
+    configure_options.add_argument(
+        '-w', '--workflow',
+        help=argparse.SUPPRESS,
+        dest='workflow',
+        nargs="+",
+        default=['download_databases'],
+    )
 
     ###########################################################################
     # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ #
@@ -894,43 +898,40 @@ def main():
         if args.busco_db_path is not None:
             Config.set_db_path(args.busco_db_path, db_name='BUSCO_DB')
 
-        if args.enrichm_db_path is not None:
-            Config.set_db_path(args.enrichm_db_path, db_name='ENRICHM_DB')
-
         if args.checkm2_db_path is not None:
             Config.set_db_path(args.checkm2_db_path, db_name='CHECKM2DB')
 
         if args.eggnog_db_path is not None:
             Config.set_db_path(args.eggnog_db_path, db_name='EGGNOG_DATA_DIR')
 
-    else:
-        args = manage_env_vars(args)
-        prefix = args.output
-        if not os.path.exists(prefix):
-            os.makedirs(prefix)
+    # else:
+    args = manage_env_vars(args)
+    prefix = args.output
+    if not os.path.exists(prefix):
+        os.makedirs(prefix)
 
-        processor = Processor(args)
+    processor = Processor(args)
 
-        processor.make_config()
-
-        if args.build:
-            try:
-                args.cmds = args.cmds + '--conda-create-envs-only '
-            except TypeError:
-                args.cmds = '--conda-create-envs-only '
+    processor.make_config()
 
+    if args.build:
         try:
-            if args.subparser_name == 'assemble':
-                if args.use_unicycler:
-                    args.workflow.insert(0, "combine_assemblies")
-        except AttributeError:
-            pass
+            args.cmds = args.cmds + '--conda-create-envs-only '
+        except TypeError:
+            args.cmds = '--conda-create-envs-only '
 
-        processor.run_workflow(cores=int(args.n_cores),
-                               dryrun=args.dryrun,
-                               clean=args.clean,
-                               conda_frontend=args.conda_frontend,
-                               snakemake_args=args.cmds)
+    try:
+        if args.subparser_name == 'assemble':
+            if args.use_unicycler:
+                args.workflow.insert(0, "combine_assemblies")
+    except AttributeError:
+        pass
+
+    processor.run_workflow(cores=int(args.n_cores),
+                           dryrun=args.dryrun,
+                           clean=args.clean,
+                           conda_frontend=args.conda_frontend,
+                           snakemake_args=args.cmds)
 
 def manage_env_vars(args):
     if args.conda_prefix is None:
@@ -940,6 +941,8 @@ def manage_env_vars(args):
             args.gtdb_path = Config.get_software_db_path('GTDBTK_DATA_PATH', '--gtdb-path')
         if args.eggnog_db_path is None:
             args.eggnog_db_path = Config.get_software_db_path('EGGNOG_DATA_DIR', '--eggnog-db-path')
+        if args.checkm2_db_path is None:
+            args.checkm2_db_path = Config.get_software_db_path('CHECKM2DB', '--checkm2-db-path')
     except AttributeError:
         pass
 
